/*
 * calcgetinfo - a command line utility to get device information from
 * a TI89 Titanium calculator over the USB link
 *
 * Copyright (C) 2010 Michael Jordan
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "ti_usb.h"
#include "ti_file.h"

int main(int argc, char *argv[]) {
	if(argc > 1) {
		string argument;
		argument.append(argv[1]);
		bool help = false;
		bool valid = false;
		if((argument == "-h") || (argument == "--help")) {
			valid = true;
			help = true;
		}
		if(!valid) help = true;
		if(help) {
			cout <<
					"\ncalcgetinfo is a utility to get device information from a\n" <<
					"TI89 Titanium calculator over the USB link.\n\n" << flush;
			cout <<
					"Keep in mind that this is, in fact, free software, developed\n" <<
					"independently and therefore comes with no warranty.\n" << flush;
			return EX_OK;
		}
	}
	cout << "Searching for calculator..." << flush;
	ti_usb calc;

	// Calling is_good() here verifies that there was a calculator located on
	// the USB bus and that we can in fact communicate with it.
	if(calc.is_good()) {
		cout << "found calculator\n";

		// Now we can talk to the calculator - let's get the info we want
		cout << "Boot version:\t" << calc.get_boot_version() << endl;
		cout << "Certificate:\t" << calc.get_cert() << endl;
		cout << "Clock mode:\t";
		if(calc.get_clock_mode() == 0) cout << "12 hour" << endl;
		else cout << "24 hour" << endl;
		cout << "Date format:\t" << calc.get_date_fmt() << endl;
		cout << "dBus dev type:\t" << calc.get_dbus_dev_type() << endl;
		cout << "Physical flash:\t" << calc.get_phys_flash() << endl;
		cout << "Free flash:\t" << calc.get_free_flash() << endl;
		cout << "Physical ram:\t" << calc.get_phys_ram() << endl;
		cout << "Free ram:\t" << calc.get_free_ram() << endl;
		cout << "Hdw version:\t" << calc.get_hdw_version() << endl;
		cout << "ID list:\t" << calc.get_id_list() << endl;
		cout << "ID string:\t" << calc.get_id_string() << endl;
		cout << "Language ID:\t" << calc.get_lang_id() << endl;
		cout << "Sublanguage ID:\t" << calc.get_sublang_id() << endl;
		cout << "LCD height:\t" << calc.get_lcd_height() << endl;
		cout << "LCD width:\t" << calc.get_lcd_width() << endl;
		cout << "OS version:\t" << calc.get_os_version() << endl;
		cout << "On homescreen:\t" << boolalpha << calc.get_homescreen_state() << endl;
		cout << "Battery good:\t" << boolalpha << calc.is_batt_good() << endl;
		cout << "OS loaded:\t" << boolalpha << calc.is_clock_enabled() << endl;
		cout << "Screen split:\t" << boolalpha << calc.is_screen_split() << endl;
		return 0;
	}
	cout << "\nNo calculator found on the USB bus\n";
	return -1;
}
